Crate kcr_k8s_otterize_com

Crate kcr_k8s_otterize_com 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the k8s.otterize.com group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

k8s.otterize.com/v1alpha2

  • ClientIntents
  • KafkaServerConfig
  • ProtectedService

k8s.otterize.com/v1alpha3

  • ClientIntents
  • KafkaServerConfig
  • ProtectedService

Modules

v1alpha2
v1alpha3