This crate contains kube-rs compatible bindings for Kubernetes custom resources for the k8s.otterize.com group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
k8s.otterize.com/v1alpha2
ClientIntentsKafkaServerConfigProtectedService
k8s.otterize.com/v1alpha3
ClientIntentsKafkaServerConfigProtectedService